function zoomsolutionmotionplotter(EFLshort,EFLlong,BFLout,OALout,f1out,f2out,f3out,f4out,solutionnumber)
% zoom plotter to plot the motion of a 4-group lens through zoom
% First and last groups are fixed, middle two groups are moving
% First run the m-file zoomplotter.m to generate different zoom lens
% solutions. Then, if you want to look at the zoom motion of a particular
% solution, run this file and input the parameters generated by
% zoomplotter.m.
%
% For example, if zoomplotter.m finds 10 solutions and you want to plot the
% zoom motion of solution 8, run:
%
% zoomsolutionmotionplotter(EFLshort,EFLlong,BFLout,OALout,f1out,f2out,f3out,f4out,8)
%
% If you want to plot all 10 solutions, run:
%
% zoomsolutionmotionplotter(EFLshort,EFLlong,BFLout,OALout,f1out,f2out,f3out,f4out,1:10)
%
% If you want to plot solutions 1, 3, and 5, run:
%
% zoomsolutionmotionplotter(EFLshort,EFLlong,BFLout,OALout,f1out,f2out,f3out,f4out,[1 3 5])

solutionnumber = solutionnumber(solutionnumber <= length(f1out));
for ij = 1:length(solutionnumber)
% % Input parameters
BFL = BFLout(solutionnumber(ij));
OAL = OALout(solutionnumber(ij));
f1 = f1out(solutionnumber(ij));
f2 = f2out(solutionnumber(ij));
f3 = f3out(solutionnumber(ij));
f4 = f4out(solutionnumber(ij));


EFL = linspace(EFLshort,EFLlong,101);
L = OAL - f1 - f4*BFL/(BFL-f4);
M = -EFL.*(OAL-L-f1)./(BFL*f1);
c = L*(f2+f3)+((M-1).^2).*f2*f3./M;

if L^2-4*1*min(c) >=0 && L^2-4*1*max(c) >= 0

% Check positive root first; a = 1;b = -L;
t2 = (L+sqrt(L^2-4*1*c))./(2*1);
x = L+((M-1).*t2+L)./((M-1)-M.*t2/f2);
t1 = OAL-x-f4*BFL/(BFL-f4);
t3 = OAL-t1-t2;
lens4z = BFL;
lens3z = t3+lens4z;
lens2z = t2+t3+lens4z;
lens1z = t1+t2+t3+lens4z;

% check for valid solutions (lens1z > lens2z > lens3z > lens4z)
if sum(lens2z > lens1z) + sum(lens3z > lens2z) + sum(lens4z > lens3z) > 0
    % There are no valid solutions
else
    figure('name',['Solution ' num2str(solutionnumber(ij))]);plot(EFL,lens1z,'b',EFL,lens2z,'r',EFL,lens3z,'g',EFL,lens4z,'m')
    xlabel('EFL (mm)');ylabel('Distance from Image (mm)');legend('Lens1','Lens2','Lens3','Lens4')
    title(['Positive Root: f_1 = ' num2str(f1) '; f_2 = ' num2str(f2) '; f_3 = ' num2str(f3) '; f_4 = ' num2str(f4)])
    pause
end

% check negative root
t2 = (L-sqrt(L^2-4*1*c))./(2*1);
x = L+((M-1).*t2+L)./((M-1)-M.*t2/f2);
t1 = OAL-x-f4*BFL/(BFL-f4);
t3 = OAL-t1-t2;
lens4z = BFL;
lens3z = t3+lens4z;
lens2z = t2+t3+lens4z;
lens1z = t1+t2+t3+lens4z;

% check for valid solutions (lens1z > lens2z > lens3z > lens4z)
if sum(lens2z > lens1z) + sum(lens3z > lens2z) + sum(lens4z > lens3z) > 0
    % There are no valid solutions
else
    figure('name',['Solution ' num2str(solutionnumber(ij))]);plot(EFL,lens1z,'b',EFL,lens2z,'r',EFL,lens3z,'g',EFL,lens4z,'m')
    xlabel('EFL (mm)');ylabel('Distance from Image (mm)');legend('Lens1','Lens2','Lens3','Lens4')
    title(['Negative Root: f_1 = ' num2str(f1) '; f_2 = ' num2str(f2) '; f_3 = ' num2str(f3) '; f_4 = ' num2str(f4)])
    pause
end
end

end
if length(solutionnumber) == 1 && exist('putvar') == 2
    ExcelVars = [EFLlong;EFLshort;f1out(solutionnumber);f2out(solutionnumber);f3out(solutionnumber);f4out(solutionnumber);BFLout(solutionnumber);OALout(solutionnumber)];
    putvar(ExcelVars)
end

end